==> graphql-language-service-utils-2.5.1.jar: META-INF/resources/webjars/graphql-language-service-utils/2.5.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.5.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.5.0...graphql-language-service-utils@2.5.1) (2021-01-07)

### Bug Fixes

- add missing nullthrows dependency to utils ([#1753](https://github.com/graphql/graphiql/issues/1753)) ([40e75a1](https://github.com/graphql/graphiql/commit/40e75a18b8fbc392c6d14e294ce9b6804b67f103))

# [2.5.0](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.4...graphql-language-service-utils@2.5.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [2.4.4](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.3...graphql-language-service-utils@2.4.4) (2021-01-03)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.2...graphql-language-service-utils@2.4.3) (2020-09-18)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.1...graphql-language-service-utils@2.4.2) (2020-09-11)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0...graphql-language-service-utils@2.4.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.9...graphql-language-service-utils@2.4.0) (2020-06-11)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.9](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.8...graphql-language-service-utils@2.4.0-alpha.9) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.8](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.7...graphql-language-service-utils@2.4.0-alpha.8) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.7](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.6...graphql-language-service-utils@2.4.0-alpha.7) (2020-05-17)

### Bug Fixes

- remove problematic file resolution module from webpack sco… ([#1489](https://github.com/graphql/graphiql/issues/1489)) ([8dab038](https://github.com/graphql/graphiql/commit/8dab0385772f443f73b559e2c668080733168236))

# [2.4.0-alpha.6](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.5...graphql-language-service-utils@2.4.0-alpha.6) (2020-04-10)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.5](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.4...graphql-language-service-utils@2.4.0-alpha.5) (2020-04-06)

### Features

- upgrade to graphql@15.0.0 for [#1191](https://github.com/graphql/graphiql/issues/1191) ([#1204](https://github.com/graphql/graphiql/issues/1204)) ([f13c8e9](https://github.com/graphql/graphiql/commit/f13c8e9d0e66df4b051b332c7d02f4bb83e07ffd))

# [2.4.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.3...graphql-language-service-utils@2.4.0-alpha.4) (2020-04-03)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.2...graphql-language-service-utils@2.4.0-alpha.3) (2020-03-20)

**Note:** Version bump only for package graphql-language-service-utils

# [2.4.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.0...graphql-language-service-utils@2.4.0-alpha.2) (2020-03-20)

### Bug Fixes

- exclusions rule for custom rules ([2bdc132](https://github.com/graphql/graphiql/commit/2bdc132abb3b1a0c5ad644e53a2c6e070a2185ce))

### Features

- use new GraphQL Config ([#1342](https://github.com/graphql/graphiql/issues/1342)) ([e45838f](https://github.com/graphql/graphiql/commit/e45838f5ba579e05b20f1a147ce431478ffad9aa))

# [2.4.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.3...graphql-language-service-utils@2.4.0-alpha.1) (2020-01-18)

### Bug Fixes

- hmr, file resolution warnings ([69bf701](https://github.com/graphql/graphiql/commit/69bf701))
- linting issues, trailingCommas: all ([#1099](https://github.com/graphql/graphiql/issues/1099)) ([de4005b](https://github.com/graphql/graphiql/commit/de4005b))

### Features

- convert LSP Server to Typescript, remove watchman ([#1138](https://github.com/graphql/graphiql/issues/1138)) ([8e33dbb](https://github.com/graphql/graphiql/commit/8e33dbb))

## [2.3.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.2...graphql-language-service-utils@2.3.3) (2019-12-09)

### Bug Fixes

- test output, webpack resolution, clean build ([3b1c2c1](https://github.com/graphql/graphiql/commit/3b1c2c1))
- **gls-utils:** [#1055](https://github.com/graphql/graphiql/issues/1055) - move file test, refactor for fixtures ([19d8d7f](https://github.com/graphql/graphiql/commit/19d8d7f))

## [2.3.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.1...graphql-language-service-utils@2.3.2) (2019-12-03)

### Bug Fixes

- convert browserify build to webpack, fixes [#976](https://github.com/graphql/graphiql/issues/976) ([#1001](https://github.com/graphql/graphiql/issues/1001)) ([3caf041](https://github.com/graphql/graphiql/commit/3caf041))

## [2.3.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.0...graphql-language-service-utils@2.3.1) (2019-11-26)

### Bug Fixes

- webpack resolutions for [#882](https://github.com/graphql/graphiql/issues/882), add webpack example ([ea9df3e](https://github.com/graphql/graphiql/commit/ea9df3e))

# 2.3.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 2.2.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 2.2.0-alpha.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

## 2.1.1-alpha.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils

## 2.1.1-alpha.0 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils

## 2.1.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils

==> graphql-language-service-utils-2.5.2.jar: META-INF/resources/webjars/graphql-language-service-utils/2.5.2/CHANGELOG.md <==
# graphql-language-service-utils

## 2.5.2

### Patch Changes

- [`6869ce77`](https://github.com/graphql/graphiql/commit/6869ce7767050787db5f1017abf82fa5a52fc97a) [#1816](https://github.com/graphql/graphiql/pull/1816) Thanks [@acao](https://github.com/acao)! - improve peer resolutions for graphql 14 & 15. `14.5.0` minimum is for built-in typescript types, and another method only available in `14.4.0`

## [2.5.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.5.0...graphql-language-service-utils@2.5.1) (2021-01-07)

### Bug Fixes

- add missing nullthrows dependency to utils ([#1753](https://github.com/graphql/graphiql/issues/1753)) ([40e75a1](https://github.com/graphql/graphiql/commit/40e75a18b8fbc392c6d14e294ce9b6804b67f103))

## [2.5.0](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.4...graphql-language-service-utils@2.5.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [2.4.4](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.3...graphql-language-service-utils@2.4.4) (2021-01-03)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.2...graphql-language-service-utils@2.4.3) (2020-09-18)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.1...graphql-language-service-utils@2.4.2) (2020-09-11)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0...graphql-language-service-utils@2.4.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.9...graphql-language-service-utils@2.4.0) (2020-06-11)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.9](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.8...graphql-language-service-utils@2.4.0-alpha.9) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.8](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.7...graphql-language-service-utils@2.4.0-alpha.8) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.7](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.6...graphql-language-service-utils@2.4.0-alpha.7) (2020-05-17)

### Bug Fixes

- remove problematic file resolution module from webpack sco… ([#1489](https://github.com/graphql/graphiql/issues/1489)) ([8dab038](https://github.com/graphql/graphiql/commit/8dab0385772f443f73b559e2c668080733168236))

## [2.4.0-alpha.6](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.5...graphql-language-service-utils@2.4.0-alpha.6) (2020-04-10)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.5](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.4...graphql-language-service-utils@2.4.0-alpha.5) (2020-04-06)

### Features

- upgrade to graphql@15.0.0 for [#1191](https://github.com/graphql/graphiql/issues/1191) ([#1204](https://github.com/graphql/graphiql/issues/1204)) ([f13c8e9](https://github.com/graphql/graphiql/commit/f13c8e9d0e66df4b051b332c7d02f4bb83e07ffd))

## [2.4.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.3...graphql-language-service-utils@2.4.0-alpha.4) (2020-04-03)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.2...graphql-language-service-utils@2.4.0-alpha.3) (2020-03-20)

**Note:** Version bump only for package graphql-language-service-utils

## [2.4.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.4.0-alpha.0...graphql-language-service-utils@2.4.0-alpha.2) (2020-03-20)

### Bug Fixes

- exclusions rule for custom rules ([2bdc132](https://github.com/graphql/graphiql/commit/2bdc132abb3b1a0c5ad644e53a2c6e070a2185ce))

### Features

- use new GraphQL Config ([#1342](https://github.com/graphql/graphiql/issues/1342)) ([e45838f](https://github.com/graphql/graphiql/commit/e45838f5ba579e05b20f1a147ce431478ffad9aa))

## [2.4.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.3...graphql-language-service-utils@2.4.0-alpha.1) (2020-01-18)

### Bug Fixes

- hmr, file resolution warnings ([69bf701](https://github.com/graphql/graphiql/commit/69bf701))
- linting issues, trailingCommas: all ([#1099](https://github.com/graphql/graphiql/issues/1099)) ([de4005b](https://github.com/graphql/graphiql/commit/de4005b))

### Features

- convert LSP Server to Typescript, remove watchman ([#1138](https://github.com/graphql/graphiql/issues/1138)) ([8e33dbb](https://github.com/graphql/graphiql/commit/8e33dbb))

## [2.3.3](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.2...graphql-language-service-utils@2.3.3) (2019-12-09)

### Bug Fixes

- test output, webpack resolution, clean build ([3b1c2c1](https://github.com/graphql/graphiql/commit/3b1c2c1))
- **gls-utils:** [#1055](https://github.com/graphql/graphiql/issues/1055) - move file test, refactor for fixtures ([19d8d7f](https://github.com/graphql/graphiql/commit/19d8d7f))

## [2.3.2](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.1...graphql-language-service-utils@2.3.2) (2019-12-03)

### Bug Fixes

- convert browserify build to webpack, fixes [#976](https://github.com/graphql/graphiql/issues/976) ([#1001](https://github.com/graphql/graphiql/issues/1001)) ([3caf041](https://github.com/graphql/graphiql/commit/3caf041))

## [2.3.1](https://github.com/graphql/graphiql/compare/graphql-language-service-utils@2.3.0...graphql-language-service-utils@2.3.1) (2019-11-26)

### Bug Fixes

- webpack resolutions for [#882](https://github.com/graphql/graphiql/issues/882), add webpack example ([ea9df3e](https://github.com/graphql/graphiql/commit/ea9df3e))

# 2.3.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 2.2.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 2.2.0-alpha.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

## 2.1.1-alpha.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils

## 2.1.1-alpha.0 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils

## 2.1.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-utils
